# streamtracer

Fast streamline tracing in python

[![Documentation Status](https://readthedocs.org/projects/streamtracer/badge/?version=latest)](https://streamtracer.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://dev.azure.com/dstansby/streamtracer/_apis/build/status/dstansby.streamtracer?branchName=master)](https://dev.azure.com/dstansby/dstansby/_build/latest?definitionId=1&branchName=master)
[![codecov](https://codecov.io/gh/dstansby/streamtracer/branch/master/graph/badge.svg)](https://codecov.io/gh/dstansby/streamtracer)


## Documentation

For full documentation, including installation instructions, see
https://streamtracer.readthedocs.io/en/latest/
